@@ -1,23 +1,9 @@
 /*
  * BluezQt - Asynchronous Bluez wrapper library
  *
- * Copyright (C) 2014 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2014 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "devicesmodel.h"
@@ -48,7 +34,7 @@ public:
 DevicesModelPrivate::DevicesModelPrivate(DevicesModel *q)
     : QObject(q)
     , q(q)
-    , m_manager(0)
+    , m_manager(nullptr)
 {
 }
 
@@ -90,7 +76,8 @@ void DevicesModelPrivate::deviceChanged(DevicePtr device)
 
 void DevicesModelPrivate::adapterChanged(AdapterPtr adapter)
 {
-    Q_FOREACH (DevicePtr device, adapter->devices()) {
+    const auto devices = adapter->devices();
+    for (const DevicePtr &device : devices) {
         deviceChanged(device);
     }
 }
@@ -117,8 +104,8 @@ QHash<int, QByteArray> DevicesModel::roleNames() const
     roles[NameRole] = QByteArrayLiteral("Name");
     roles[FriendlyNameRole] = QByteArrayLiteral("FriendlyName");
     roles[RemoteNameRole] = QByteArrayLiteral("RemoteName");
-    roles[DeviceClassRole] = QByteArrayLiteral("DeviceClass");
-    roles[DeviceTypeRole] = QByteArrayLiteral("DeviceType");
+    roles[ClassRole] = QByteArrayLiteral("Class");
+    roles[TypeRole] = QByteArrayLiteral("Type");
     roles[AppearanceRole] = QByteArrayLiteral("Appearance");
     roles[IconRole] = QByteArrayLiteral("Icon");
     roles[PairedRole] = QByteArrayLiteral("Paired");
@@ -168,10 +155,10 @@ QVariant DevicesModel::data(const QModelIndex &index, int role) const
         return dev->friendlyName();
     case RemoteNameRole:
         return dev->remoteName();
-    case DeviceClassRole:
+    case ClassRole:
         return dev->deviceClass();
-    case DeviceTypeRole:
-        return dev->deviceType();
+    case TypeRole:
+        return dev->type();
     case AppearanceRole:
         return dev->appearance();
     case IconRole:
